<?php

use QUI\ERP\Payments\Stripe\PaymentMethods\Recurring\BillingPlans;
use QUI\Utils\Security\Orthos;

/**
 * Delete a Stripe Billing Plan
 *
 * @param string $planId - Stripe Billing Plan ID
 * @return bool - success
 */
QUI::$Ajax->registerFunction(
    'package_quiqqer_payment-stripe_ajax_backend_settings_deleteBillingPlan',
    function ($planId) {
        $planId = Orthos::clear($planId);

        try {
            BillingPlans::deleteBillingPlan($planId);
        } catch (\Exception $Exception) {
            QUI\System\Log::writeException($Exception);

            QUI::getMessagesHandler()->addError(
                QUI::getLocale()->get(
                    'quiqqer/payment-stripe',
                    'message.ajax.backend.settings.deleteBillingPlan.error',
                    [
                        'error'   => $Exception->getMessage(),
                        'plandId' => $planId
                    ]
                )
            );

            return false;
        }

        QUI::getMessagesHandler()->addSuccess(
            QUI::getLocale()->get(
                'quiqqer/payment-stripe',
                'message.ajax.backend.settings.deleteBillingPlan.success',
                [
                    'plandId' => $planId
                ]
            )
        );

        return true;
    },
    ['planId'],
    ['Permission::checkAdminUser', 'quiqqer.payments.stripe.billing_plans.delete']
);
