<?php

use QUI\System\VhostManager;
use QUI\ERP\Payments\Stripe\Provider;
use Stripe\Stripe as StripeApiClient;
use Stripe\ApplePayDomain;

/**
 * Get registration status data for Apple Pay domains
 *
 * @return array
 */
QUI::$Ajax->registerFunction(
    'package_quiqqer_payment-stripe_ajax_backend_settings_getApplePayData',
    function () {
        $VhostManager = new VhostManager();
        $vhosts       = $VhostManager->getList();
        $clientSecret = Provider::getClientSecret(false);

        if (empty($clientSecret)) {
            QUI::getMessagesHandler()->addError(
                QUI::getLocale()->get(
                    'quiqqer/payment-stripe',
                    'message.ajax.backend.settings.registerApplePayDomain.error.secret_key_required'
                )
            );

            return [];
        }

        StripeApiClient::setApiKey($clientSecret);

        $applePayDomains = ApplePayDomain::all()->toArray();
        $applePayDomains = $applePayDomains['data'];

        $registered = \array_fill_keys(\array_keys($vhosts), false);

        foreach ($applePayDomains as $entry) {
            if (isset($registered[$entry['domain_name']])) {
                $registered[$entry['domain_name']] = true;
            }
        }

        return $registered;
    },
    [],
    ['Permission::checkAdminUser']
);
