<?php

use QUI\ERP\Order\Handler;
use QUI\Utils\Security\Orthos;
use QUI\ERP\Payments\Stripe\StripeException;

/**
 * Confirm a Stripe PaymentIntent
 *
 * @param int $basketId - Basket ID
 * @return array - PaymentIntent data
 */
QUI::$Ajax->registerFunction(
    'package_quiqqer_payment-stripe_ajax_confirmPaymentIntent',
    function ($orderHash) {
        try {
            $orderHash = Orthos::clear($orderHash);
            $Order     = Handler::getInstance()->getOrderByHash($orderHash);

            /** @var \QUI\ERP\Payments\Stripe\AbstractBasePayment $Payment */
            $Payment             = $Order->getPayment()->getPaymentType();
            $StripePaymentIntent = $Payment->getPaymentIntentByOrder($Order);

            return $Payment->confirmPaymentIntent($Order, $StripePaymentIntent);
        } catch (\Exception $Exception) {
            QUI\System\Log::writeException($Exception);

            throw new StripeException([
                'quiqqer/payment-stripe',
                'exception.ajax.createPaymentIntent.general_error'
            ]);
        }
    },
    ['orderHash'],
    'Permission::checkUser'
);
