/**
 * QUIQQER JavaScript API for Stripe
 *
 * @author Patrick Müller (www.pcsg.de)
 */
define('package/quiqqer/payment-stripe/bin/classes/Stripe', [

    'Ajax'

], function (QUIAjax) {
    "use strict";

    var pkg = 'quiqqer/payment-stripe';

    return new Class({

        Type: 'package/quiqqer/payment-stripe/bin/classes/Stripe',

        /**
         * Create a Stripe PaymentIntent
         *
         * @param {String} orderHash - Unique order hash
         * @param {String} paymentMethodId - Stripe PaymentMethod ID
         * @return {Promise}
         */
        createPaymentIntent: function (orderHash, paymentMethodId) {
            return new Promise(function (resolve, reject) {
                QUIAjax.post('package_quiqqer_payment-stripe_ajax_createPaymentIntent', resolve, {
                    'package'      : pkg,
                    orderHash      : orderHash,
                    paymentMethodId: paymentMethodId,
                    onError        : reject,
                    showError      : false
                })
            });
        },

        /**
         * Confirm a Stripe PaymentIntent
         *
         * @param {String} orderHash - Unique order hash
         * @return {Promise}
         */
        confirmPaymentIntent: function (orderHash) {
            return new Promise(function (resolve, reject) {
                QUIAjax.post('package_quiqqer_payment-stripe_ajax_confirmPaymentIntent', resolve, {
                    'package': pkg,
                    orderHash: orderHash,
                    onError  : reject,
                    showError: false
                })
            });
        },

        /**
         * Create a Stripe Subscription
         *
         * @param {String} orderHash - Unique order hash
         * @param {String} paymentMethodId - Stripe PaymentMethod ID
         * @param {Boolean} [resetPaymentMethod]
         * @return {Promise}
         */
        createSubscription: function (orderHash, paymentMethodId, resetPaymentMethod) {
            return new Promise(function (resolve, reject) {
                QUIAjax.post('package_quiqqer_payment-stripe_ajax_createSubscription', resolve, {
                    'package'         : pkg,
                    orderHash         : orderHash,
                    paymentMethodId   : paymentMethodId,
                    resetPaymentMethod: resetPaymentMethod ? 1 : 0,
                    onError           : reject,
                    showError         : false
                })
            });
        },

        /**
         * Confirm a Stripe Subscription
         *
         * @param {String} orderHash - Unique order hash
         * @return {Promise}
         */
        confirmSubscription: function (orderHash) {
            return new Promise(function (resolve, reject) {
                QUIAjax.post('package_quiqqer_payment-stripe_ajax_confirmSubscription', resolve, {
                    'package': pkg,
                    orderHash: orderHash,
                    onError  : reject,
                    showError: false
                })
            });
        },

        /**
         * Get Stripe Billing Plan list
         *
         * @param {Object} SearchParams
         * @return {Promise}
         */
        getBillingPlans: function (SearchParams) {
            return new Promise(function (resolve, reject) {
                QUIAjax.get('package_quiqqer_payment-stripe_ajax_backend_settings_getBillingPlans', resolve, {
                    'package'   : pkg,
                    searchParams: JSON.encode(SearchParams),
                    onError     : reject,
                    showError   : false
                })
            });
        },

        /**
         * Delete Stripe Billing Plan
         *
         * @param {String} planId
         * @return {Promise}
         */
        deleteBillingPlan: function (planId) {
            return new Promise(function (resolve, reject) {
                QUIAjax.post('package_quiqqer_payment-stripe_ajax_backend_settings_deleteBillingPlan', resolve, {
                    'package': pkg,
                    planId   : planId,
                    onError  : reject,
                    showError: false
                })
            });
        },

        /**
         * Get Stripe Subscriptions list
         *
         * @param {Object} SearchParams
         * @return {Promise}
         */
        getSubscriptions: function (SearchParams) {
            return new Promise(function (resolve, reject) {
                QUIAjax.get('package_quiqqer_payment-stripe_ajax_backend_settings_getSubscriptions', resolve, {
                    'package'   : pkg,
                    searchParams: JSON.encode(SearchParams),
                    onError     : reject,
                    showError   : false
                })
            });
        },

        /**
         * Get data of a single Stripe Subscription
         *
         * @param {String} subscriptionId
         * @return {Promise}
         */
        getSubscription: function (subscriptionId) {
            return new Promise(function (resolve, reject) {
                QUIAjax.get('package_quiqqer_payment-stripe_ajax_backend_settings_getSubscription', resolve, {
                    'package'     : pkg,
                    subscriptionId: subscriptionId,
                    onError       : reject,
                    showError     : false
                })
            });
        },

        /**
         * Cancel Stripe Subscriptions
         *
         * @param {String} subscriptionId
         * @return {Promise}
         */
        cancelSubscription: function (subscriptionId) {
            return new Promise(function (resolve, reject) {
                QUIAjax.get('package_quiqqer_payment-stripe_ajax_backend_settings_cancelSubscription', resolve, {
                    'package'     : pkg,
                    subscriptionId: subscriptionId,
                    onError       : reject,
                    showError     : false
                })
            });
        }
    });
});