<?php

namespace QUI\ERP\Payments\Stripe\PaymentMethods;

use QUI;
use QUI\ERP\Accounting\Payments\Payments;
use QUI\ERP\Order\AbstractOrder;
use QUI\ERP\Payments\Stripe\AbstractBasePayment;
use Stripe\Exception\ApiErrorException;
use Stripe\PaymentIntent as StripePaymentIntent;
use QUI\ERP\Payments\Stripe\Utils;

/**
 * Class BrowserPay
 *
 * Stripe payment via Browser (includes GooglePay, ApplePay, Microsoft Pay, Browser Payment Request API)
 */
abstract class AbstractBrowserPay extends AbstractBasePayment
{
    /**
     * Return the payment icon (the URL path)
     * Can be overwritten
     *
     * @return string
     */
    public function getIcon()
    {
        // @todo
        return Payments::getInstance()->getHost().
               URL_OPT_DIR.
               'quiqqer/payment-stripe/bin/images/Payment.png';
    }

    /**
     * Get type of Browser this BrowserPay works with
     *
     * @return string
     */
    abstract public function getBrowserType();

    /**
     * Get type string of Stripe PaymentMethod
     *
     * @return string
     */
    public function getPaymentMethodType()
    {
        return 'browser_pay';
    }

    /**
     * Return attributes for creating a PaymentIntent
     *
     * @param AbstractOrder $Order
     * @param string $paymentMethodId - Stripe PaymentMethod ID
     * @return StripePaymentIntent
     *
     * @throws ApiErrorException
     * @throws QUI\Exception
     */
    protected function createPaymentIntentForOrder(AbstractOrder $Order, $paymentMethodId)
    {
        return StripePaymentIntent::create([
            'payment_method'      => $paymentMethodId,
            'amount'              => Utils::getCentAmount($Order),
            'currency'            => mb_strtolower($Order->getCurrency()->getCode()),
            'confirmation_method' => 'manual',
            'confirm'             => true,
        ]);
    }
}
