<?php

namespace QUI\ERP\Payments\Stripe\PaymentMethods\Recurring;

use QUI\ERP\Accounting\Payments\Payments;

/**
 * Class MicrosoftPay
 *
 * Recurring payments via Microsoft Pay
 */
class MicrosoftPay extends AbstractRecurringBrowserPay
{
    /**
     * @return string
     */
    public function getTitle()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.Recurring.MicrosoftPay.title');
    }

    /**
     * @return string
     */
    public function getDescription()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.Recurring.MicrosoftPay.description');
    }

    /**
     * Get title for frontend
     *
     * @return string
     */
    public function getFrontendTitle()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.frontend.Recurring.MicrosoftPay.title');
    }

    /**
     * Get description for frontend
     *
     * @return string
     */
    public function getFrontendDescription()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.frontend.Recurring.MicrosoftPay.description');
    }

    /**
     * Get title for the Payment step (OrderProcess)
     *
     * @return string
     */
    public function getPaymentStepTitle()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.PaymentStep.title.MicrosoftPay');
    }

    /**
     * Get description step for the Payment step (OrderProcess)
     *
     * @return string
     */
    public function getPaymentStepInfo()
    {
        return $this->getLocale()->get('quiqqer/payment-stripe', 'payment.PaymentStep.info.MicrosoftPay');
    }

    /**
     * Get type of Browser this BrowserPay works with
     *
     * @return string
     */
    public function getBrowserType()
    {
        return \Browser::BROWSER_EDGE;
    }

    /**
     * Return the payment icon (the URL path)
     * Can be overwritten
     *
     * @return string
     */
    public function getIcon()
    {
        return Payments::getInstance()->getHost().
               URL_OPT_DIR.
               'quiqqer/payment-stripe/bin/images/Payment_MicrosoftPay.png';
    }
}
